/*
 * Copyright (c) 1998,1999,2000,2003 Damien Miller.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* Routines to extract data from network packets */

#ifndef _PACKET_PARSE_H
#define _PACKET_PARSE_H

#include <sys/types.h>

typedef struct 
{
	int			datalink_type;
	u_int8_t		src_hw_addr[6];
	u_int8_t		dst_hw_addr[6];
	u_int32_t	src_ip_addr;
	u_int32_t	dst_ip_addr;
	u_int16_t	ip_protocol;
	u_int32_t	src_port;
	u_int32_t	dst_port;
	u_int16_t	total_length;
	u_int16_t	header_length;
	int			is_fragment;
	int			is_connection_request;
	time_t		received_time;
} packet_info_t;

/* Parse a packet, filling structure pinfo */
/* Returns 1 on success, 0 on error */
int parse_packet(int link_type, const unsigned char *pkt, 
                 unsigned int len, packet_info_t *pinfo);

/* Returns a string describing the last error to occur */
/* The error string is cleared at each call to parse_packet() */
const char *parse_error(void);

#endif
