/*
 * Copyright (c) 1998,1999,2000,2003 Damien Miller.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* Data structures used to store packet summary information */

#ifndef _SUMMARY_STRUCTURES_H
#define _SUMMARY_STRUCTURES_H

#include <time.h>
#include <sys/types.h>
#include <glib.h>

typedef struct
{
	u_int64_t		key;
	struct HOST		*host1;
	struct HOST		*host2;
	u_int64_t		bytes_sent_1_to_2;
	u_int64_t		bytes_sent_2_to_1;
	u_int64_t		packets_sent_1_to_2;
	u_int64_t		packets_sent_2_to_1;
	u_int64_t		connections_sent_1_to_2;
	u_int64_t		connections_sent_2_to_1;
	time_t			first_seen;
	time_t			last_seen;
} peer_t;

typedef struct HOST
{
	u_int32_t		ip_addr;
	char				*hostname;
	u_int64_t		bytes_sent;
	u_int64_t		bytes_received;
	u_int64_t		packets_sent;
	u_int64_t		packets_received;
	u_int64_t		connections_sent;
	u_int64_t		connections_received;
	time_t			first_seen;
	time_t			last_seen;
	u_int64_t		*peer_keys;
	unsigned long	n_peers;
} host_t;

typedef struct
{
	u_int64_t		total_bytes;
	u_int64_t		total_packets;
	u_int64_t		total_connections;
	time_t			summary_start;
	time_t			summary_finish;
	u_int32_t		active_hosts;
	GHashTable		*hosts;
	GHashTable		*peers;
} summary_t;

#endif /* _SUMMARY_STRUCTURES_H */
