/*
 * Copyright (c) 1998,1999,2000,2003 Damien Miller.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* Main module for report text generation for traffic-vis */

#include <stdlib.h>
#include <stdio.h>
#include <getopt.h>
#include <time.h>
#include <sys/types.h>

#include "util.h"
#include "report.h"
#include "read-report.h"
#include "sort-report.h"
#include "textfe.h"

static char			rcsid[] = "$Id: traffic-totext.c,v 1.5 2003/06/20 07:07:17 djm Exp $";

#ifdef HAVE_GETOPT_LONG
/* Commandline options */
static struct option long_options[] =
{
	{"input", 1, NULL, 'i'},
	{"output", 1, NULL, 'o'},
	{"version", 0, NULL, 'V'},
	{"help", 0, NULL, 'h'},
	{NULL, 0, NULL, 0}
};
#endif /* HAVE_GETOPT_LONG */

/* Prototypes */
void usage(void);
void version(void);
int main(int argc, char **argv);

void usage(void)
{
	fprintf(stderr, "Usage: traffic-tops [OPTION]\n");

	fprintf(stderr, "\n");

	fprintf(stderr, "Filter which convers a network traffic summary created by traffic-collector\n");
	fprintf(stderr, "into a text report.\n");

	fprintf(stderr, "\n");

#ifdef HAVE_GETOPT_LONG
	fprintf(stderr, "  -i, --input  file    Read input from 'file' instead of stdin.\n");
	fprintf(stderr, "  -o, --output file    Write output to 'file' instead of stdout.\n");
	fprintf(stderr, "  -V, --version        Print program version.\n");
	fprintf(stderr, "  -h, --help           Display this help text.\n");
#else /* HAVE_GETOPT_LONG */
	fprintf(stderr, "  -i file  Read input from 'file' instead of stdin.\n");
	fprintf(stderr, "  -o file  Write output to 'file' instead of stdout.\n");
	fprintf(stderr, "  -V	    Print program version.\n");
	fprintf(stderr, "  -h	    Display this help text.\n");
#endif /* HAVE_GETOPT_LONG */

	fprintf(stderr, "\n");

	fprintf(stderr, "Please report bugs to dmiller@ilogic.com.au\n");
}

void version(void)
{
	fprintf(stderr, "traffic-totext %s\n", VERSION);
}

int main(int argc, char **argv)
{
	report_t			*r;

	int 				c;
	extern char 	*optarg;
	
	/* Commandline options */
	static char		*output_file = NULL;
	static char		*input_file = NULL;
	
	/* Fetch commandline options */
	while (1)
	{
#ifdef HAVE_GETOPT_LONG
		c = getopt_long (argc, argv, "o:i:hV?", long_options, NULL);
#else /* HAVE_GETOPT_LONG */
		c = getopt (argc, argv, "o:i:hV?");
#endif /* HAVE_GETOPT_LONG */
		if (c == -1)
			break;
		
		switch (c)
		{
			case 'i':
				input_file = util_strdup(optarg);
				break;
				
			case 'o':
				output_file = util_strdup(optarg);
				break;
				
			case 'V':
				version();
				exit(0);
				
			case 'h':
			case '?':
				usage();
				exit(0);
				
			default:
				fprintf(stderr, "Invalid commandline options.\n\n");
				usage();
				exit(-1);
		}
	}

	r = parse_report(input_file);
	
	text_display_summary(r, output_file);

	return(0);
}
