#!/bin/sh

# Copyright (c) 1998,1999,2000,2003 Damien Miller.  All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

set -x

YYYYMMDD=`date "+%Y%m%d"`
TODAY_LOG=/var/log/traffic-vis/traffic.today
KEEP_LOG=/var/log/traffic-vis/traffic.$YYYYMMDD
HTML_REPORT=/home/httpd/html/traffic-vis/report-$YYYYMMDD.html
GIF_REPORT=/home/httpd/html/traffic-vis/report-$YYYYMMDD.gif

rm -f $TODAY_LOG 2>/dev/null

if ! /usr/bin/killall -USR2 traffic-collector ; then
	echo "traffic-collector is not running"
	exit 1
fi

for t in 0 1 2 3 4 5 6 7 8 9 ; do
	sleep 20
	if [ -f $TODAY_LOG ] ; then
		sleep 20 # Ensure that traffic-collect has a chance to finish writing
		break
	fi
done

if [ ! -f $TODAY_LOG ] ; then
	echo "traffic-collect did not write log after 200 seconds"
	exit 1
fi

if ! /bin/mv -f $TODAY_LOG $KEEP_LOG ; then
	echo "Couldn't move logfile to permanent location"
	exit 1
fi

/usr/sbin/traffic-sort		--host-sort bytes --peer-sort bytes \
									--limit-hosts 80 --limit-peers 80 \
									--input $KEEP_LOG --output $KEEP_LOG.sort

/usr/sbin/traffic-resolve	--input $KEEP_LOG.sort --output $KEEP_LOG.res

/usr/sbin/traffic-tohtml	--input $KEEP_LOG.res --output $HTML_REPORT

/usr/sbin/traffic-togif		--x-size 600 --y-size 600 \
									--input $KEEP_LOG.res --output $GIF_REPORT

rm -f $KEEP_LOG.sort $KEEP_LOG.res

gzip -9 $KEEP_LOG
rm -f $KEEP_LOG
